# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetVpcResult',
    'AwaitableGetVpcResult',
    'get_vpc',
    'get_vpc_output',
]

@pulumi.output_type
class GetVpcResult:
    """
    A collection of values returned by getVpc.
    """
    def __init__(__self__, created_at=None, default=None, description=None, id=None, ip_range=None, name=None, region=None, urn=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_range and not isinstance(ip_range, str):
            raise TypeError("Expected argument 'ip_range' to be a str")
        pulumi.set(__self__, "ip_range", ip_range)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of when the VPC was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def default(self) -> _builtins.bool:
        """
        A boolean indicating whether or not the VPC is the default one for the region.
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        A free-form text field describing the VPC.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier for the VPC.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipRange")
    def ip_range(self) -> _builtins.str:
        """
        The range of IP addresses for the VPC in CIDR notation.
        """
        return pulumi.get(self, "ip_range")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the VPC.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The DigitalOcean region slug for the VPC's location.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def urn(self) -> _builtins.str:
        """
        The uniform resource name (URN) for the VPC.
        """
        return pulumi.get(self, "urn")


class AwaitableGetVpcResult(GetVpcResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcResult(
            created_at=self.created_at,
            default=self.default,
            description=self.description,
            id=self.id,
            ip_range=self.ip_range,
            name=self.name,
            region=self.region,
            urn=self.urn)


def get_vpc(id: Optional[_builtins.str] = None,
            name: Optional[_builtins.str] = None,
            region: Optional[_builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcResult:
    """
    Retrieve information about a VPC for use in other resources.

    This data source provides all of the VPC's properties as configured on your
    DigitalOcean account. This is useful if the VPC in question is not managed by
    the provider or you need to utilize any of the VPC's data.

    VPCs may be looked up by `id` or `name`. Specifying a `region` will
    return that that region's default VPC.

    ## Example Usage

    ### VPC By Name

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_vpc(name="example-network")
    ```

    Reuse the data about a VPC to assign a Droplet to it:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_vpc(name="example-network")
    example_droplet = digitalocean.Droplet("example",
        name="example-01",
        size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
        image="ubuntu-18-04-x64",
        region=digitalocean.Region.NYC3,
        vpc_uuid=example.id)
    ```


    :param _builtins.str id: The unique identifier of an existing VPC.
    :param _builtins.str name: The name of an existing VPC.
    :param _builtins.str region: The DigitalOcean region slug for the VPC's location.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getVpc:getVpc', __args__, opts=opts, typ=GetVpcResult).value

    return AwaitableGetVpcResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        default=pulumi.get(__ret__, 'default'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ip_range=pulumi.get(__ret__, 'ip_range'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        urn=pulumi.get(__ret__, 'urn'))
def get_vpc_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpcResult]:
    """
    Retrieve information about a VPC for use in other resources.

    This data source provides all of the VPC's properties as configured on your
    DigitalOcean account. This is useful if the VPC in question is not managed by
    the provider or you need to utilize any of the VPC's data.

    VPCs may be looked up by `id` or `name`. Specifying a `region` will
    return that that region's default VPC.

    ## Example Usage

    ### VPC By Name

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_vpc(name="example-network")
    ```

    Reuse the data about a VPC to assign a Droplet to it:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_vpc(name="example-network")
    example_droplet = digitalocean.Droplet("example",
        name="example-01",
        size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
        image="ubuntu-18-04-x64",
        region=digitalocean.Region.NYC3,
        vpc_uuid=example.id)
    ```


    :param _builtins.str id: The unique identifier of an existing VPC.
    :param _builtins.str name: The name of an existing VPC.
    :param _builtins.str region: The DigitalOcean region slug for the VPC's location.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getVpc:getVpc', __args__, opts=opts, typ=GetVpcResult)
    return __ret__.apply(lambda __response__: GetVpcResult(
        created_at=pulumi.get(__response__, 'created_at'),
        default=pulumi.get(__response__, 'default'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        ip_range=pulumi.get(__response__, 'ip_range'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        urn=pulumi.get(__response__, 'urn')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetProjectResult',
    'AwaitableGetProjectResult',
    'get_project',
    'get_project_output',
]

@pulumi.output_type
class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, created_at=None, description=None, environment=None, id=None, is_default=None, name=None, owner_id=None, owner_uuid=None, purpose=None, resources=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment and not isinstance(environment, str):
            raise TypeError("Expected argument 'environment' to be a str")
        pulumi.set(__self__, "environment", environment)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner_id and not isinstance(owner_id, int):
            raise TypeError("Expected argument 'owner_id' to be a int")
        pulumi.set(__self__, "owner_id", owner_id)
        if owner_uuid and not isinstance(owner_uuid, str):
            raise TypeError("Expected argument 'owner_uuid' to be a str")
        pulumi.set(__self__, "owner_uuid", owner_uuid)
        if purpose and not isinstance(purpose, str):
            raise TypeError("Expected argument 'purpose' to be a str")
        pulumi.set(__self__, "purpose", purpose)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time when the project was created, (ISO8601)
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the project
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> _builtins.str:
        """
        The environment of the project's resources. The possible values are: `Development`, `Staging`, `Production`.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> _builtins.int:
        """
        The ID of the project owner.
        """
        return pulumi.get(self, "owner_id")

    @_builtins.property
    @pulumi.getter(name="ownerUuid")
    def owner_uuid(self) -> _builtins.str:
        """
        The unique universal identifier of the project owner.
        """
        return pulumi.get(self, "owner_uuid")

    @_builtins.property
    @pulumi.getter
    def purpose(self) -> _builtins.str:
        """
        The purpose of the project, (Default: "Web Application")
        """
        return pulumi.get(self, "purpose")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Sequence[_builtins.str]:
        """
        A set of uniform resource names (URNs) for the resources associated with the project
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time when the project was last updated, (ISO8601)
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            created_at=self.created_at,
            description=self.description,
            environment=self.environment,
            id=self.id,
            is_default=self.is_default,
            name=self.name,
            owner_id=self.owner_id,
            owner_uuid=self.owner_uuid,
            purpose=self.purpose,
            resources=self.resources,
            updated_at=self.updated_at)


def get_project(id: Optional[_builtins.str] = None,
                name: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectResult:
    """
    Get information on a single DigitalOcean project. If neither the `id` nor `name` attributes are provided,
    then this data source returns the default project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    default = digitalocean.get_project()
    staging = digitalocean.get_project(name="My Staging Project")
    ```


    :param _builtins.str id: the ID of the project to retrieve
    :param _builtins.str name: the name of the project to retrieve. The data source will raise an error if more than
           one project has the provided name or if no project has that name.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getProject:getProject', __args__, opts=opts, typ=GetProjectResult).value

    return AwaitableGetProjectResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        environment=pulumi.get(__ret__, 'environment'),
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        name=pulumi.get(__ret__, 'name'),
        owner_id=pulumi.get(__ret__, 'owner_id'),
        owner_uuid=pulumi.get(__ret__, 'owner_uuid'),
        purpose=pulumi.get(__ret__, 'purpose'),
        resources=pulumi.get(__ret__, 'resources'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_project_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectResult]:
    """
    Get information on a single DigitalOcean project. If neither the `id` nor `name` attributes are provided,
    then this data source returns the default project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    default = digitalocean.get_project()
    staging = digitalocean.get_project(name="My Staging Project")
    ```


    :param _builtins.str id: the ID of the project to retrieve
    :param _builtins.str name: the name of the project to retrieve. The data source will raise an error if more than
           one project has the provided name or if no project has that name.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getProject:getProject', __args__, opts=opts, typ=GetProjectResult)
    return __ret__.apply(lambda __response__: GetProjectResult(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        environment=pulumi.get(__response__, 'environment'),
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        name=pulumi.get(__response__, 'name'),
        owner_id=pulumi.get(__response__, 'owner_id'),
        owner_uuid=pulumi.get(__response__, 'owner_uuid'),
        purpose=pulumi.get(__response__, 'purpose'),
        resources=pulumi.get(__response__, 'resources'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDatabaseCaResult',
    'AwaitableGetDatabaseCaResult',
    'get_database_ca',
    'get_database_ca_output',
]

@pulumi.output_type
class GetDatabaseCaResult:
    """
    A collection of values returned by getDatabaseCa.
    """
    def __init__(__self__, certificate=None, cluster_id=None, id=None):
        if certificate and not isinstance(certificate, str):
            raise TypeError("Expected argument 'certificate' to be a str")
        pulumi.set(__self__, "certificate", certificate)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> _builtins.str:
        """
        The CA certificate used to secure database connections decoded to a string.
        """
        return pulumi.get(self, "certificate")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> _builtins.str:
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetDatabaseCaResult(GetDatabaseCaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseCaResult(
            certificate=self.certificate,
            cluster_id=self.cluster_id,
            id=self.id)


def get_database_ca(cluster_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseCaResult:
    """
    Provides the CA certificate for a DigitalOcean database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    ca = digitalocean.get_database_ca(cluster_id="aaa-bbb-ccc-ddd")
    pulumi.export("caOutput", ca.certificate)
    ```


    :param _builtins.str cluster_id: The ID of the source database cluster.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getDatabaseCa:getDatabaseCa', __args__, opts=opts, typ=GetDatabaseCaResult).value

    return AwaitableGetDatabaseCaResult(
        certificate=pulumi.get(__ret__, 'certificate'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'))
def get_database_ca_output(cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseCaResult]:
    """
    Provides the CA certificate for a DigitalOcean database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    ca = digitalocean.get_database_ca(cluster_id="aaa-bbb-ccc-ddd")
    pulumi.export("caOutput", ca.certificate)
    ```


    :param _builtins.str cluster_id: The ID of the source database cluster.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getDatabaseCa:getDatabaseCa', __args__, opts=opts, typ=GetDatabaseCaResult)
    return __ret__.apply(lambda __response__: GetDatabaseCaResult(
        certificate=pulumi.get(__response__, 'certificate'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSshKeysResult',
    'AwaitableGetSshKeysResult',
    'get_ssh_keys',
    'get_ssh_keys_output',
]

@pulumi.output_type
class GetSshKeysResult:
    """
    A collection of values returned by getSshKeys.
    """
    def __init__(__self__, filters=None, id=None, sorts=None, ssh_keys=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if sorts and not isinstance(sorts, list):
            raise TypeError("Expected argument 'sorts' to be a list")
        pulumi.set(__self__, "sorts", sorts)
        if ssh_keys and not isinstance(ssh_keys, list):
            raise TypeError("Expected argument 'ssh_keys' to be a list")
        pulumi.set(__self__, "ssh_keys", ssh_keys)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetSshKeysFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def sorts(self) -> Optional[Sequence['outputs.GetSshKeysSortResult']]:
        return pulumi.get(self, "sorts")

    @_builtins.property
    @pulumi.getter(name="sshKeys")
    def ssh_keys(self) -> Sequence['outputs.GetSshKeysSshKeyResult']:
        """
        A list of SSH Keys. Each SSH Key has the following attributes:
        """
        return pulumi.get(self, "ssh_keys")


class AwaitableGetSshKeysResult(GetSshKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSshKeysResult(
            filters=self.filters,
            id=self.id,
            sorts=self.sorts,
            ssh_keys=self.ssh_keys)


def get_ssh_keys(filters: Optional[Sequence[Union['GetSshKeysFilterArgs', 'GetSshKeysFilterArgsDict']]] = None,
                 sorts: Optional[Sequence[Union['GetSshKeysSortArgs', 'GetSshKeysSortArgsDict']]] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSshKeysResult:
    """
    Get information on SSH Keys for use in other resources.

    This data source is useful if the SSH Keys in question are not managed by the provider or you need to
    utilize any of the SSH Keys' data.

    Note: You can use the `SshKey` data source to obtain metadata
    about a single SSH Key if you already know the unique `name` to retrieve.

    ## Example Usage

    For example, to find all SSH keys:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    keys = digitalocean.get_ssh_keys(sorts=[{
        "key": "name",
        "direction": "asc",
    }])
    ```

    Or to find ones matching specific values:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    keys = digitalocean.get_ssh_keys(filters=[{
        "key": "name",
        "values": [
            "laptop",
            "desktop",
        ],
    }])
    ```


    :param Sequence[Union['GetSshKeysFilterArgs', 'GetSshKeysFilterArgsDict']] filters: Filter the results.
           The `filter` block is documented below.
    :param Sequence[Union['GetSshKeysSortArgs', 'GetSshKeysSortArgsDict']] sorts: Sort the results.
           The `sort` block is documented below.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['sorts'] = sorts
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getSshKeys:getSshKeys', __args__, opts=opts, typ=GetSshKeysResult).value

    return AwaitableGetSshKeysResult(
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        sorts=pulumi.get(__ret__, 'sorts'),
        ssh_keys=pulumi.get(__ret__, 'ssh_keys'))
def get_ssh_keys_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetSshKeysFilterArgs', 'GetSshKeysFilterArgsDict']]]]] = None,
                        sorts: Optional[pulumi.Input[Optional[Sequence[Union['GetSshKeysSortArgs', 'GetSshKeysSortArgsDict']]]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSshKeysResult]:
    """
    Get information on SSH Keys for use in other resources.

    This data source is useful if the SSH Keys in question are not managed by the provider or you need to
    utilize any of the SSH Keys' data.

    Note: You can use the `SshKey` data source to obtain metadata
    about a single SSH Key if you already know the unique `name` to retrieve.

    ## Example Usage

    For example, to find all SSH keys:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    keys = digitalocean.get_ssh_keys(sorts=[{
        "key": "name",
        "direction": "asc",
    }])
    ```

    Or to find ones matching specific values:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    keys = digitalocean.get_ssh_keys(filters=[{
        "key": "name",
        "values": [
            "laptop",
            "desktop",
        ],
    }])
    ```


    :param Sequence[Union['GetSshKeysFilterArgs', 'GetSshKeysFilterArgsDict']] filters: Filter the results.
           The `filter` block is documented below.
    :param Sequence[Union['GetSshKeysSortArgs', 'GetSshKeysSortArgsDict']] sorts: Sort the results.
           The `sort` block is documented below.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['sorts'] = sorts
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getSshKeys:getSshKeys', __args__, opts=opts, typ=GetSshKeysResult)
    return __ret__.apply(lambda __response__: GetSshKeysResult(
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        sorts=pulumi.get(__response__, 'sorts'),
        ssh_keys=pulumi.get(__response__, 'ssh_keys')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppArgs', 'App']

@pulumi.input_type
class AppArgs:
    def __init__(__self__, *,
                 dedicated_ips: Optional[pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input['AppSpecArgs']] = None):
        """
        The set of arguments for constructing a App resource.
        :param pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]] dedicated_ips: The dedicated egress IP addresses associated with the app.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that the app is assigned to.
               
               A spec can contain multiple components.
               
               A `service` can contain:
        :param pulumi.Input['AppSpecArgs'] spec: A DigitalOcean App spec describing the app.
        """
        if dedicated_ips is not None:
            pulumi.set(__self__, "dedicated_ips", dedicated_ips)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)

    @_builtins.property
    @pulumi.getter(name="dedicatedIps")
    def dedicated_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]]]:
        """
        The dedicated egress IP addresses associated with the app.
        """
        return pulumi.get(self, "dedicated_ips")

    @dedicated_ips.setter
    def dedicated_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]]]):
        pulumi.set(self, "dedicated_ips", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project that the app is assigned to.

        A spec can contain multiple components.

        A `service` can contain:
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['AppSpecArgs']]:
        """
        A DigitalOcean App spec describing the app.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['AppSpecArgs']]):
        pulumi.set(self, "spec", value)


@pulumi.input_type
class _AppState:
    def __init__(__self__, *,
                 active_deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 app_urn: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 dedicated_ips: Optional[pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]]] = None,
                 default_ingress: Optional[pulumi.Input[_builtins.str]] = None,
                 live_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 live_url: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input['AppSpecArgs']] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering App resources.
        :param pulumi.Input[_builtins.str] active_deployment_id: The ID the app's currently active deployment.
        :param pulumi.Input[_builtins.str] app_urn: The uniform resource identifier for the app.
        :param pulumi.Input[_builtins.str] created_at: The date and time of when the app was created.
        :param pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]] dedicated_ips: The dedicated egress IP addresses associated with the app.
        :param pulumi.Input[_builtins.str] default_ingress: The default URL to access the app.
        :param pulumi.Input[_builtins.str] live_domain: The live domain of the app.
        :param pulumi.Input[_builtins.str] live_url: The live URL of the app.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that the app is assigned to.
               
               A spec can contain multiple components.
               
               A `service` can contain:
        :param pulumi.Input['AppSpecArgs'] spec: A DigitalOcean App spec describing the app.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of when the app was last updated.
        """
        if active_deployment_id is not None:
            pulumi.set(__self__, "active_deployment_id", active_deployment_id)
        if app_urn is not None:
            pulumi.set(__self__, "app_urn", app_urn)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if dedicated_ips is not None:
            pulumi.set(__self__, "dedicated_ips", dedicated_ips)
        if default_ingress is not None:
            pulumi.set(__self__, "default_ingress", default_ingress)
        if live_domain is not None:
            pulumi.set(__self__, "live_domain", live_domain)
        if live_url is not None:
            pulumi.set(__self__, "live_url", live_url)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="activeDeploymentId")
    def active_deployment_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID the app's currently active deployment.
        """
        return pulumi.get(self, "active_deployment_id")

    @active_deployment_id.setter
    def active_deployment_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "active_deployment_id", value)

    @_builtins.property
    @pulumi.getter(name="appUrn")
    def app_urn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The uniform resource identifier for the app.
        """
        return pulumi.get(self, "app_urn")

    @app_urn.setter
    def app_urn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_urn", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of when the app was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="dedicatedIps")
    def dedicated_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]]]:
        """
        The dedicated egress IP addresses associated with the app.
        """
        return pulumi.get(self, "dedicated_ips")

    @dedicated_ips.setter
    def dedicated_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppDedicatedIpArgs']]]]):
        pulumi.set(self, "dedicated_ips", value)

    @_builtins.property
    @pulumi.getter(name="defaultIngress")
    def default_ingress(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default URL to access the app.
        """
        return pulumi.get(self, "default_ingress")

    @default_ingress.setter
    def default_ingress(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_ingress", value)

    @_builtins.property
    @pulumi.getter(name="liveDomain")
    def live_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The live domain of the app.
        """
        return pulumi.get(self, "live_domain")

    @live_domain.setter
    def live_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "live_domain", value)

    @_builtins.property
    @pulumi.getter(name="liveUrl")
    def live_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The live URL of the app.
        """
        return pulumi.get(self, "live_url")

    @live_url.setter
    def live_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "live_url", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project that the app is assigned to.

        A spec can contain multiple components.

        A `service` can contain:
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['AppSpecArgs']]:
        """
        A DigitalOcean App spec describing the app.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['AppSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of when the app was last updated.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("digitalocean:index/app:App")
class App(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dedicated_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppDedicatedIpArgs', 'AppDedicatedIpArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['AppSpecArgs', 'AppSpecArgsDict']]] = None,
                 __props__=None):
        """
        Provides a DigitalOcean App resource.

        ## Example Usage

        To create an app, provide a [DigitalOcean app spec](https://docs.digitalocean.com/products/app-platform/reference/app-spec/) specifying the app's components.

        ### Basic Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        golang_sample = digitalocean.App("golang-sample", spec={
            "name": "golang-sample",
            "region": "ams",
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ### Static Site Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        static_site_example = digitalocean.App("static-site-example", spec={
            "name": "static-site-example",
            "region": "ams",
            "static_sites": [{
                "name": "sample-jekyll",
                "build_command": "bundle exec jekyll build -d ./public",
                "output_dir": "/public",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-jekyll.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ### Log Destination Example with Opensearch

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        golang_sample = digitalocean.App("golang-sample", spec={
            "name": "golang-sample",
            "region": "ams",
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
                "log_destinations": [{
                    "name": "MyLogs",
                    "open_search": {
                        "endpoint": "https://something:1234",
                        "basic_auth": {
                            "user": "user",
                            "password": "hi",
                        },
                    },
                }],
            }],
        })
        ```

        ### Edge Controls Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        golang_sample = digitalocean.App("golang-sample", spec={
            "name": "golang-sample",
            "region": "ams",
            "disable_edge_cache": True,
            "disable_email_obfuscation": False,
            "enhanced_threat_control_enabled": True,
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ### Maintenance Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        maintenance_example = digitalocean.App("maintenance-example", spec={
            "name": "maintenance-example",
            "region": "ams",
            "maintenance": {
                "enabled": True,
                "offline_page_url": "https://example.com/maintenance.html",
            },
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ## Import

        An app can be imported using its `id`, e.g.

        ```sh
        $ pulumi import digitalocean:index/app:App myapp fb06ad00-351f-45c8-b5eb-13523c438661
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppDedicatedIpArgs', 'AppDedicatedIpArgsDict']]]] dedicated_ips: The dedicated egress IP addresses associated with the app.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that the app is assigned to.
               
               A spec can contain multiple components.
               
               A `service` can contain:
        :param pulumi.Input[Union['AppSpecArgs', 'AppSpecArgsDict']] spec: A DigitalOcean App spec describing the app.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AppArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DigitalOcean App resource.

        ## Example Usage

        To create an app, provide a [DigitalOcean app spec](https://docs.digitalocean.com/products/app-platform/reference/app-spec/) specifying the app's components.

        ### Basic Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        golang_sample = digitalocean.App("golang-sample", spec={
            "name": "golang-sample",
            "region": "ams",
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ### Static Site Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        static_site_example = digitalocean.App("static-site-example", spec={
            "name": "static-site-example",
            "region": "ams",
            "static_sites": [{
                "name": "sample-jekyll",
                "build_command": "bundle exec jekyll build -d ./public",
                "output_dir": "/public",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-jekyll.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ### Log Destination Example with Opensearch

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        golang_sample = digitalocean.App("golang-sample", spec={
            "name": "golang-sample",
            "region": "ams",
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
                "log_destinations": [{
                    "name": "MyLogs",
                    "open_search": {
                        "endpoint": "https://something:1234",
                        "basic_auth": {
                            "user": "user",
                            "password": "hi",
                        },
                    },
                }],
            }],
        })
        ```

        ### Edge Controls Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        golang_sample = digitalocean.App("golang-sample", spec={
            "name": "golang-sample",
            "region": "ams",
            "disable_edge_cache": True,
            "disable_email_obfuscation": False,
            "enhanced_threat_control_enabled": True,
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ### Maintenance Example

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        maintenance_example = digitalocean.App("maintenance-example", spec={
            "name": "maintenance-example",
            "region": "ams",
            "maintenance": {
                "enabled": True,
                "offline_page_url": "https://example.com/maintenance.html",
            },
            "services": [{
                "name": "go-service",
                "instance_count": 1,
                "instance_size_slug": "apps-s-1vcpu-1gb",
                "git": {
                    "repo_clone_url": "https://github.com/digitalocean/sample-golang.git",
                    "branch": "main",
                },
            }],
        })
        ```

        ## Import

        An app can be imported using its `id`, e.g.

        ```sh
        $ pulumi import digitalocean:index/app:App myapp fb06ad00-351f-45c8-b5eb-13523c438661
        ```

        :param str resource_name: The name of the resource.
        :param AppArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dedicated_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppDedicatedIpArgs', 'AppDedicatedIpArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['AppSpecArgs', 'AppSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppArgs.__new__(AppArgs)

            __props__.__dict__["dedicated_ips"] = dedicated_ips
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["spec"] = spec
            __props__.__dict__["active_deployment_id"] = None
            __props__.__dict__["app_urn"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["default_ingress"] = None
            __props__.__dict__["live_domain"] = None
            __props__.__dict__["live_url"] = None
            __props__.__dict__["updated_at"] = None
        super(App, __self__).__init__(
            'digitalocean:index/app:App',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active_deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
            app_urn: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            dedicated_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppDedicatedIpArgs', 'AppDedicatedIpArgsDict']]]]] = None,
            default_ingress: Optional[pulumi.Input[_builtins.str]] = None,
            live_domain: Optional[pulumi.Input[_builtins.str]] = None,
            live_url: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            spec: Optional[pulumi.Input[Union['AppSpecArgs', 'AppSpecArgsDict']]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'App':
        """
        Get an existing App resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] active_deployment_id: The ID the app's currently active deployment.
        :param pulumi.Input[_builtins.str] app_urn: The uniform resource identifier for the app.
        :param pulumi.Input[_builtins.str] created_at: The date and time of when the app was created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppDedicatedIpArgs', 'AppDedicatedIpArgsDict']]]] dedicated_ips: The dedicated egress IP addresses associated with the app.
        :param pulumi.Input[_builtins.str] default_ingress: The default URL to access the app.
        :param pulumi.Input[_builtins.str] live_domain: The live domain of the app.
        :param pulumi.Input[_builtins.str] live_url: The live URL of the app.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project that the app is assigned to.
               
               A spec can contain multiple components.
               
               A `service` can contain:
        :param pulumi.Input[Union['AppSpecArgs', 'AppSpecArgsDict']] spec: A DigitalOcean App spec describing the app.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of when the app was last updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppState.__new__(_AppState)

        __props__.__dict__["active_deployment_id"] = active_deployment_id
        __props__.__dict__["app_urn"] = app_urn
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["dedicated_ips"] = dedicated_ips
        __props__.__dict__["default_ingress"] = default_ingress
        __props__.__dict__["live_domain"] = live_domain
        __props__.__dict__["live_url"] = live_url
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["spec"] = spec
        __props__.__dict__["updated_at"] = updated_at
        return App(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="activeDeploymentId")
    def active_deployment_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID the app's currently active deployment.
        """
        return pulumi.get(self, "active_deployment_id")

    @_builtins.property
    @pulumi.getter(name="appUrn")
    def app_urn(self) -> pulumi.Output[_builtins.str]:
        """
        The uniform resource identifier for the app.
        """
        return pulumi.get(self, "app_urn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of when the app was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="dedicatedIps")
    def dedicated_ips(self) -> pulumi.Output[Sequence['outputs.AppDedicatedIp']]:
        """
        The dedicated egress IP addresses associated with the app.
        """
        return pulumi.get(self, "dedicated_ips")

    @_builtins.property
    @pulumi.getter(name="defaultIngress")
    def default_ingress(self) -> pulumi.Output[_builtins.str]:
        """
        The default URL to access the app.
        """
        return pulumi.get(self, "default_ingress")

    @_builtins.property
    @pulumi.getter(name="liveDomain")
    def live_domain(self) -> pulumi.Output[_builtins.str]:
        """
        The live domain of the app.
        """
        return pulumi.get(self, "live_domain")

    @_builtins.property
    @pulumi.getter(name="liveUrl")
    def live_url(self) -> pulumi.Output[_builtins.str]:
        """
        The live URL of the app.
        """
        return pulumi.get(self, "live_url")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project that the app is assigned to.

        A spec can contain multiple components.

        A `service` can contain:
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Output[Optional['outputs.AppSpec']]:
        """
        A DigitalOcean App spec describing the app.
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of when the app was last updated.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ContainerRegistryDockerCredentialsArgs', 'ContainerRegistryDockerCredentials']

@pulumi.input_type
class ContainerRegistryDockerCredentialsArgs:
    def __init__(__self__, *,
                 registry_name: pulumi.Input[_builtins.str],
                 expiry_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 write: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ContainerRegistryDockerCredentials resource.
        :param pulumi.Input[_builtins.str] registry_name: The name of the container registry.
        :param pulumi.Input[_builtins.int] expiry_seconds: The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        :param pulumi.Input[_builtins.bool] write: Allow for write access to the container registry. Defaults to false.
        """
        pulumi.set(__self__, "registry_name", registry_name)
        if expiry_seconds is not None:
            pulumi.set(__self__, "expiry_seconds", expiry_seconds)
        if write is not None:
            pulumi.set(__self__, "write", write)

    @_builtins.property
    @pulumi.getter(name="registryName")
    def registry_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the container registry.
        """
        return pulumi.get(self, "registry_name")

    @registry_name.setter
    def registry_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "registry_name", value)

    @_builtins.property
    @pulumi.getter(name="expirySeconds")
    def expiry_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        """
        return pulumi.get(self, "expiry_seconds")

    @expiry_seconds.setter
    def expiry_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "expiry_seconds", value)

    @_builtins.property
    @pulumi.getter
    def write(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow for write access to the container registry. Defaults to false.
        """
        return pulumi.get(self, "write")

    @write.setter
    def write(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "write", value)


@pulumi.input_type
class _ContainerRegistryDockerCredentialsState:
    def __init__(__self__, *,
                 credential_expiration_time: Optional[pulumi.Input[_builtins.str]] = None,
                 docker_credentials: Optional[pulumi.Input[_builtins.str]] = None,
                 expiry_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 registry_name: Optional[pulumi.Input[_builtins.str]] = None,
                 write: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ContainerRegistryDockerCredentials resources.
        :param pulumi.Input[_builtins.str] credential_expiration_time: The date and time the registry access token will expire.
        :param pulumi.Input[_builtins.str] docker_credentials: Credentials for the container registry.
        :param pulumi.Input[_builtins.int] expiry_seconds: The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        :param pulumi.Input[_builtins.str] registry_name: The name of the container registry.
        :param pulumi.Input[_builtins.bool] write: Allow for write access to the container registry. Defaults to false.
        """
        if credential_expiration_time is not None:
            pulumi.set(__self__, "credential_expiration_time", credential_expiration_time)
        if docker_credentials is not None:
            pulumi.set(__self__, "docker_credentials", docker_credentials)
        if expiry_seconds is not None:
            pulumi.set(__self__, "expiry_seconds", expiry_seconds)
        if registry_name is not None:
            pulumi.set(__self__, "registry_name", registry_name)
        if write is not None:
            pulumi.set(__self__, "write", write)

    @_builtins.property
    @pulumi.getter(name="credentialExpirationTime")
    def credential_expiration_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the registry access token will expire.
        """
        return pulumi.get(self, "credential_expiration_time")

    @credential_expiration_time.setter
    def credential_expiration_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credential_expiration_time", value)

    @_builtins.property
    @pulumi.getter(name="dockerCredentials")
    def docker_credentials(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Credentials for the container registry.
        """
        return pulumi.get(self, "docker_credentials")

    @docker_credentials.setter
    def docker_credentials(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "docker_credentials", value)

    @_builtins.property
    @pulumi.getter(name="expirySeconds")
    def expiry_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        """
        return pulumi.get(self, "expiry_seconds")

    @expiry_seconds.setter
    def expiry_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "expiry_seconds", value)

    @_builtins.property
    @pulumi.getter(name="registryName")
    def registry_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the container registry.
        """
        return pulumi.get(self, "registry_name")

    @registry_name.setter
    def registry_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_name", value)

    @_builtins.property
    @pulumi.getter
    def write(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow for write access to the container registry. Defaults to false.
        """
        return pulumi.get(self, "write")

    @write.setter
    def write(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "write", value)


@pulumi.type_token("digitalocean:index/containerRegistryDockerCredentials:ContainerRegistryDockerCredentials")
class ContainerRegistryDockerCredentials(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expiry_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 registry_name: Optional[pulumi.Input[_builtins.str]] = None,
                 write: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Get Docker credentials for your DigitalOcean container registry.

        An error is triggered if the provided container registry name does not exist.

        ## Example Usage

        ### Basic Example

        Get the container registry:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.ContainerRegistryDockerCredentials("example", registry_name="example")
        ```

        ### Docker Provider Example

        Use the `endpoint` and `docker_credentials` with the Docker provider:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.get_container_registry(name="example")
        example_container_registry_docker_credentials = digitalocean.ContainerRegistryDockerCredentials("example", registry_name="example")
        ```

        ### Kubernetes Example

        Combined with the Kubernetes Provider's `kubernetes_secret` resource, you can
        access the registry from inside your cluster:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean
        import pulumi_kubernetes as kubernetes

        example_container_registry_docker_credentials = digitalocean.ContainerRegistryDockerCredentials("example", registry_name="example")
        example = digitalocean.get_kubernetes_cluster(name="prod-cluster-01")
        example_secret = kubernetes.core.v1.Secret("example",
            metadata={
                "name": "docker-cfg",
            },
            data={
                ".dockerconfigjson": example_container_registry_docker_credentials.docker_credentials,
            },
            type="kubernetes.io/dockerconfigjson")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] expiry_seconds: The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        :param pulumi.Input[_builtins.str] registry_name: The name of the container registry.
        :param pulumi.Input[_builtins.bool] write: Allow for write access to the container registry. Defaults to false.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContainerRegistryDockerCredentialsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Get Docker credentials for your DigitalOcean container registry.

        An error is triggered if the provided container registry name does not exist.

        ## Example Usage

        ### Basic Example

        Get the container registry:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.ContainerRegistryDockerCredentials("example", registry_name="example")
        ```

        ### Docker Provider Example

        Use the `endpoint` and `docker_credentials` with the Docker provider:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example = digitalocean.get_container_registry(name="example")
        example_container_registry_docker_credentials = digitalocean.ContainerRegistryDockerCredentials("example", registry_name="example")
        ```

        ### Kubernetes Example

        Combined with the Kubernetes Provider's `kubernetes_secret` resource, you can
        access the registry from inside your cluster:

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean
        import pulumi_kubernetes as kubernetes

        example_container_registry_docker_credentials = digitalocean.ContainerRegistryDockerCredentials("example", registry_name="example")
        example = digitalocean.get_kubernetes_cluster(name="prod-cluster-01")
        example_secret = kubernetes.core.v1.Secret("example",
            metadata={
                "name": "docker-cfg",
            },
            data={
                ".dockerconfigjson": example_container_registry_docker_credentials.docker_credentials,
            },
            type="kubernetes.io/dockerconfigjson")
        ```

        :param str resource_name: The name of the resource.
        :param ContainerRegistryDockerCredentialsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContainerRegistryDockerCredentialsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expiry_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 registry_name: Optional[pulumi.Input[_builtins.str]] = None,
                 write: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContainerRegistryDockerCredentialsArgs.__new__(ContainerRegistryDockerCredentialsArgs)

            __props__.__dict__["expiry_seconds"] = expiry_seconds
            if registry_name is None and not opts.urn:
                raise TypeError("Missing required property 'registry_name'")
            __props__.__dict__["registry_name"] = registry_name
            __props__.__dict__["write"] = write
            __props__.__dict__["credential_expiration_time"] = None
            __props__.__dict__["docker_credentials"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["dockerCredentials"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ContainerRegistryDockerCredentials, __self__).__init__(
            'digitalocean:index/containerRegistryDockerCredentials:ContainerRegistryDockerCredentials',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            credential_expiration_time: Optional[pulumi.Input[_builtins.str]] = None,
            docker_credentials: Optional[pulumi.Input[_builtins.str]] = None,
            expiry_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            registry_name: Optional[pulumi.Input[_builtins.str]] = None,
            write: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ContainerRegistryDockerCredentials':
        """
        Get an existing ContainerRegistryDockerCredentials resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] credential_expiration_time: The date and time the registry access token will expire.
        :param pulumi.Input[_builtins.str] docker_credentials: Credentials for the container registry.
        :param pulumi.Input[_builtins.int] expiry_seconds: The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        :param pulumi.Input[_builtins.str] registry_name: The name of the container registry.
        :param pulumi.Input[_builtins.bool] write: Allow for write access to the container registry. Defaults to false.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContainerRegistryDockerCredentialsState.__new__(_ContainerRegistryDockerCredentialsState)

        __props__.__dict__["credential_expiration_time"] = credential_expiration_time
        __props__.__dict__["docker_credentials"] = docker_credentials
        __props__.__dict__["expiry_seconds"] = expiry_seconds
        __props__.__dict__["registry_name"] = registry_name
        __props__.__dict__["write"] = write
        return ContainerRegistryDockerCredentials(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="credentialExpirationTime")
    def credential_expiration_time(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the registry access token will expire.
        """
        return pulumi.get(self, "credential_expiration_time")

    @_builtins.property
    @pulumi.getter(name="dockerCredentials")
    def docker_credentials(self) -> pulumi.Output[_builtins.str]:
        """
        Credentials for the container registry.
        """
        return pulumi.get(self, "docker_credentials")

    @_builtins.property
    @pulumi.getter(name="expirySeconds")
    def expiry_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The amount of time to pass before the Docker credentials expire in seconds. Defaults to 1576800000, or roughly 50 years. Must be greater than 0 and less than 1576800000.
        """
        return pulumi.get(self, "expiry_seconds")

    @_builtins.property
    @pulumi.getter(name="registryName")
    def registry_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the container registry.
        """
        return pulumi.get(self, "registry_name")

    @_builtins.property
    @pulumi.getter
    def write(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Allow for write access to the container registry. Defaults to false.
        """
        return pulumi.get(self, "write")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GenaiFunctionArgs', 'GenaiFunction']

@pulumi.input_type
class GenaiFunctionArgs:
    def __init__(__self__, *,
                 agent_id: pulumi.Input[_builtins.str],
                 description: pulumi.Input[_builtins.str],
                 faas_namespace: pulumi.Input[_builtins.str],
                 function_name: pulumi.Input[_builtins.str],
                 input_schema: pulumi.Input[_builtins.str],
                 faas_name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_schema: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GenaiFunction resource.
        :param pulumi.Input[_builtins.str] agent_id: The name of the GenAI resource.
        :param pulumi.Input[_builtins.str] description: The region where the GenAI resource will be created.
        :param pulumi.Input[_builtins.str] faas_namespace: The current status of the GenAI resource.
        :param pulumi.Input[_builtins.str] function_name: The creation timestamp of the GenAI resource.
        :param pulumi.Input[_builtins.str] input_schema: The input schema of the GenAI resource.
        :param pulumi.Input[_builtins.str] faas_name: The model to use for the GenAI resource.
        :param pulumi.Input[_builtins.str] output_schema: The output schema of the GenAI resource.
        """
        pulumi.set(__self__, "agent_id", agent_id)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "faas_namespace", faas_namespace)
        pulumi.set(__self__, "function_name", function_name)
        pulumi.set(__self__, "input_schema", input_schema)
        if faas_name is not None:
            pulumi.set(__self__, "faas_name", faas_name)
        if output_schema is not None:
            pulumi.set(__self__, "output_schema", output_schema)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the GenAI resource.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        The region where the GenAI resource will be created.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="faasNamespace")
    def faas_namespace(self) -> pulumi.Input[_builtins.str]:
        """
        The current status of the GenAI resource.
        """
        return pulumi.get(self, "faas_namespace")

    @faas_namespace.setter
    def faas_namespace(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "faas_namespace", value)

    @_builtins.property
    @pulumi.getter(name="functionName")
    def function_name(self) -> pulumi.Input[_builtins.str]:
        """
        The creation timestamp of the GenAI resource.
        """
        return pulumi.get(self, "function_name")

    @function_name.setter
    def function_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "function_name", value)

    @_builtins.property
    @pulumi.getter(name="inputSchema")
    def input_schema(self) -> pulumi.Input[_builtins.str]:
        """
        The input schema of the GenAI resource.
        """
        return pulumi.get(self, "input_schema")

    @input_schema.setter
    def input_schema(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "input_schema", value)

    @_builtins.property
    @pulumi.getter(name="faasName")
    def faas_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The model to use for the GenAI resource.
        """
        return pulumi.get(self, "faas_name")

    @faas_name.setter
    def faas_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "faas_name", value)

    @_builtins.property
    @pulumi.getter(name="outputSchema")
    def output_schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The output schema of the GenAI resource.
        """
        return pulumi.get(self, "output_schema")

    @output_schema.setter
    def output_schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "output_schema", value)


@pulumi.input_type
class _GenaiFunctionState:
    def __init__(__self__, *,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 faas_name: Optional[pulumi.Input[_builtins.str]] = None,
                 faas_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 function_name: Optional[pulumi.Input[_builtins.str]] = None,
                 function_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 input_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 output_schema: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GenaiFunction resources.
        :param pulumi.Input[_builtins.str] agent_id: The name of the GenAI resource.
        :param pulumi.Input[_builtins.str] description: The region where the GenAI resource will be created.
        :param pulumi.Input[_builtins.str] faas_name: The model to use for the GenAI resource.
        :param pulumi.Input[_builtins.str] faas_namespace: The current status of the GenAI resource.
        :param pulumi.Input[_builtins.str] function_name: The creation timestamp of the GenAI resource.
        :param pulumi.Input[_builtins.str] function_uuid: The unique identifier of the GenAI function.
        :param pulumi.Input[_builtins.str] input_schema: The input schema of the GenAI resource.
        :param pulumi.Input[_builtins.str] output_schema: The output schema of the GenAI resource.
        """
        if agent_id is not None:
            pulumi.set(__self__, "agent_id", agent_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if faas_name is not None:
            pulumi.set(__self__, "faas_name", faas_name)
        if faas_namespace is not None:
            pulumi.set(__self__, "faas_namespace", faas_namespace)
        if function_name is not None:
            pulumi.set(__self__, "function_name", function_name)
        if function_uuid is not None:
            pulumi.set(__self__, "function_uuid", function_uuid)
        if input_schema is not None:
            pulumi.set(__self__, "input_schema", input_schema)
        if output_schema is not None:
            pulumi.set(__self__, "output_schema", output_schema)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the GenAI resource.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where the GenAI resource will be created.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="faasName")
    def faas_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The model to use for the GenAI resource.
        """
        return pulumi.get(self, "faas_name")

    @faas_name.setter
    def faas_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "faas_name", value)

    @_builtins.property
    @pulumi.getter(name="faasNamespace")
    def faas_namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The current status of the GenAI resource.
        """
        return pulumi.get(self, "faas_namespace")

    @faas_namespace.setter
    def faas_namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "faas_namespace", value)

    @_builtins.property
    @pulumi.getter(name="functionName")
    def function_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The creation timestamp of the GenAI resource.
        """
        return pulumi.get(self, "function_name")

    @function_name.setter
    def function_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "function_name", value)

    @_builtins.property
    @pulumi.getter(name="functionUuid")
    def function_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the GenAI function.
        """
        return pulumi.get(self, "function_uuid")

    @function_uuid.setter
    def function_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "function_uuid", value)

    @_builtins.property
    @pulumi.getter(name="inputSchema")
    def input_schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The input schema of the GenAI resource.
        """
        return pulumi.get(self, "input_schema")

    @input_schema.setter
    def input_schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "input_schema", value)

    @_builtins.property
    @pulumi.getter(name="outputSchema")
    def output_schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The output schema of the GenAI resource.
        """
        return pulumi.get(self, "output_schema")

    @output_schema.setter
    def output_schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "output_schema", value)


@pulumi.type_token("digitalocean:index/genaiFunction:GenaiFunction")
class GenaiFunction(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 faas_name: Optional[pulumi.Input[_builtins.str]] = None,
                 faas_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 function_name: Optional[pulumi.Input[_builtins.str]] = None,
                 input_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 output_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a GenaiFunction resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_id: The name of the GenAI resource.
        :param pulumi.Input[_builtins.str] description: The region where the GenAI resource will be created.
        :param pulumi.Input[_builtins.str] faas_name: The model to use for the GenAI resource.
        :param pulumi.Input[_builtins.str] faas_namespace: The current status of the GenAI resource.
        :param pulumi.Input[_builtins.str] function_name: The creation timestamp of the GenAI resource.
        :param pulumi.Input[_builtins.str] input_schema: The input schema of the GenAI resource.
        :param pulumi.Input[_builtins.str] output_schema: The output schema of the GenAI resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GenaiFunctionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a GenaiFunction resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param GenaiFunctionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GenaiFunctionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 faas_name: Optional[pulumi.Input[_builtins.str]] = None,
                 faas_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 function_name: Optional[pulumi.Input[_builtins.str]] = None,
                 input_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 output_schema: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GenaiFunctionArgs.__new__(GenaiFunctionArgs)

            if agent_id is None and not opts.urn:
                raise TypeError("Missing required property 'agent_id'")
            __props__.__dict__["agent_id"] = agent_id
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["faas_name"] = faas_name
            if faas_namespace is None and not opts.urn:
                raise TypeError("Missing required property 'faas_namespace'")
            __props__.__dict__["faas_namespace"] = faas_namespace
            if function_name is None and not opts.urn:
                raise TypeError("Missing required property 'function_name'")
            __props__.__dict__["function_name"] = function_name
            if input_schema is None and not opts.urn:
                raise TypeError("Missing required property 'input_schema'")
            __props__.__dict__["input_schema"] = input_schema
            __props__.__dict__["output_schema"] = output_schema
            __props__.__dict__["function_uuid"] = None
        super(GenaiFunction, __self__).__init__(
            'digitalocean:index/genaiFunction:GenaiFunction',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            faas_name: Optional[pulumi.Input[_builtins.str]] = None,
            faas_namespace: Optional[pulumi.Input[_builtins.str]] = None,
            function_name: Optional[pulumi.Input[_builtins.str]] = None,
            function_uuid: Optional[pulumi.Input[_builtins.str]] = None,
            input_schema: Optional[pulumi.Input[_builtins.str]] = None,
            output_schema: Optional[pulumi.Input[_builtins.str]] = None) -> 'GenaiFunction':
        """
        Get an existing GenaiFunction resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_id: The name of the GenAI resource.
        :param pulumi.Input[_builtins.str] description: The region where the GenAI resource will be created.
        :param pulumi.Input[_builtins.str] faas_name: The model to use for the GenAI resource.
        :param pulumi.Input[_builtins.str] faas_namespace: The current status of the GenAI resource.
        :param pulumi.Input[_builtins.str] function_name: The creation timestamp of the GenAI resource.
        :param pulumi.Input[_builtins.str] function_uuid: The unique identifier of the GenAI function.
        :param pulumi.Input[_builtins.str] input_schema: The input schema of the GenAI resource.
        :param pulumi.Input[_builtins.str] output_schema: The output schema of the GenAI resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GenaiFunctionState.__new__(_GenaiFunctionState)

        __props__.__dict__["agent_id"] = agent_id
        __props__.__dict__["description"] = description
        __props__.__dict__["faas_name"] = faas_name
        __props__.__dict__["faas_namespace"] = faas_namespace
        __props__.__dict__["function_name"] = function_name
        __props__.__dict__["function_uuid"] = function_uuid
        __props__.__dict__["input_schema"] = input_schema
        __props__.__dict__["output_schema"] = output_schema
        return GenaiFunction(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the GenAI resource.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        The region where the GenAI resource will be created.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="faasName")
    def faas_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The model to use for the GenAI resource.
        """
        return pulumi.get(self, "faas_name")

    @_builtins.property
    @pulumi.getter(name="faasNamespace")
    def faas_namespace(self) -> pulumi.Output[_builtins.str]:
        """
        The current status of the GenAI resource.
        """
        return pulumi.get(self, "faas_namespace")

    @_builtins.property
    @pulumi.getter(name="functionName")
    def function_name(self) -> pulumi.Output[_builtins.str]:
        """
        The creation timestamp of the GenAI resource.
        """
        return pulumi.get(self, "function_name")

    @_builtins.property
    @pulumi.getter(name="functionUuid")
    def function_uuid(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the GenAI function.
        """
        return pulumi.get(self, "function_uuid")

    @_builtins.property
    @pulumi.getter(name="inputSchema")
    def input_schema(self) -> pulumi.Output[_builtins.str]:
        """
        The input schema of the GenAI resource.
        """
        return pulumi.get(self, "input_schema")

    @_builtins.property
    @pulumi.getter(name="outputSchema")
    def output_schema(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The output schema of the GenAI resource.
        """
        return pulumi.get(self, "output_schema")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .app import *
from .cdn import *
from .certificate import *
from .container_registry import *
from .container_registry_docker_credentials import *
from .custom_image import *
from .database_cluster import *
from .database_connection_pool import *
from .database_db import *
from .database_firewall import *
from .database_kafka_config import *
from .database_kafka_topic import *
from .database_mongodb_config import *
from .database_mysql_config import *
from .database_online_migration import *
from .database_opensearch_config import *
from .database_postgresql_config import *
from .database_redis_config import *
from .database_replica import *
from .database_user import *
from .database_valkey_config import *
from .dns_record import *
from .domain import *
from .droplet import *
from .droplet_autoscale import *
from .droplet_snapshot import *
from .firewall import *
from .floating_ip import *
from .floating_ip_assignment import *
from .genai_agent import *
from .genai_agent_knowledge_base_attachment import *
from .genai_agent_route import *
from .genai_function import *
from .genai_knowledge_base import *
from .genai_knowledge_base_data_source import *
from .genai_openai_api_key import *
from .get_account import *
from .get_app import *
from .get_certificate import *
from .get_container_registry import *
from .get_database_ca import *
from .get_database_cluster import *
from .get_database_connection_pool import *
from .get_database_metrics_credentials import *
from .get_database_replica import *
from .get_database_user import *
from .get_domain import *
from .get_domains import *
from .get_droplet import *
from .get_droplet_autoscale import *
from .get_droplet_snapshot import *
from .get_droplets import *
from .get_firewall import *
from .get_floating_ip import *
from .get_genai_agent import *
from .get_genai_agent_versions import *
from .get_genai_agents import *
from .get_genai_agents_by_openai_api_key import *
from .get_genai_knowledge_base import *
from .get_genai_knowledge_base_data_sources import *
from .get_genai_knowledge_bases import *
from .get_genai_openai_api_key import *
from .get_genai_openai_api_keys import *
from .get_image import *
from .get_images import *
from .get_kubernetes_cluster import *
from .get_kubernetes_versions import *
from .get_load_balancer import *
from .get_partner_attachment import *
from .get_partner_attachment_service_key import *
from .get_project import *
from .get_projects import *
from .get_record import *
from .get_records import *
from .get_region import *
from .get_regions import *
from .get_reserved_ip import *
from .get_reserved_ipv6 import *
from .get_sizes import *
from .get_spaces_bucket import *
from .get_spaces_bucket_object import *
from .get_spaces_bucket_objects import *
from .get_spaces_buckets import *
from .get_spaces_key import *
from .get_ssh_key import *
from .get_ssh_keys import *
from .get_tag import *
from .get_tags import *
from .get_volume import *
from .get_volume_snapshot import *
from .get_vpc import *
from .get_vpc_nat_gateway import *
from .get_vpc_peering import *
from .kubernetes_cluster import *
from .kubernetes_node_pool import *
from .load_balancer import *
from .monitor_alert import *
from .partner_attachment import *
from .project import *
from .project_resources import *
from .provider import *
from .reserved_ip import *
from .reserved_ip_assignment import *
from .reserved_ipv6 import *
from .reserved_ipv6_assignment import *
from .spaces_bucket import *
from .spaces_bucket_cors_configuration import *
from .spaces_bucket_logging import *
from .spaces_bucket_object import *
from .spaces_bucket_policy import *
from .spaces_key import *
from .ssh_key import *
from .tag import *
from .uptime_alert import *
from .uptime_check import *
from .volume import *
from .volume_attachment import *
from .volume_snapshot import *
from .vpc import *
from .vpc_nat_gateway import *
from .vpc_peering import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_digitalocean.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_digitalocean.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "digitalocean",
  "mod": "index/app",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/app:App": "App"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/cdn",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/cdn:Cdn": "Cdn"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/certificate",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/containerRegistry",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/containerRegistry:ContainerRegistry": "ContainerRegistry"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/containerRegistryDockerCredentials",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/containerRegistryDockerCredentials:ContainerRegistryDockerCredentials": "ContainerRegistryDockerCredentials"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/customImage",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/customImage:CustomImage": "CustomImage"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseCluster",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseCluster:DatabaseCluster": "DatabaseCluster"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseConnectionPool",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseConnectionPool:DatabaseConnectionPool": "DatabaseConnectionPool"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseDb",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseDb:DatabaseDb": "DatabaseDb"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseFirewall",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseFirewall:DatabaseFirewall": "DatabaseFirewall"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseKafkaConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseKafkaConfig:DatabaseKafkaConfig": "DatabaseKafkaConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseKafkaTopic",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseKafkaTopic:DatabaseKafkaTopic": "DatabaseKafkaTopic"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseMongodbConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseMongodbConfig:DatabaseMongodbConfig": "DatabaseMongodbConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseMysqlConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseMysqlConfig:DatabaseMysqlConfig": "DatabaseMysqlConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseOnlineMigration",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseOnlineMigration:DatabaseOnlineMigration": "DatabaseOnlineMigration"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseOpensearchConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseOpensearchConfig:DatabaseOpensearchConfig": "DatabaseOpensearchConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databasePostgresqlConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databasePostgresqlConfig:DatabasePostgresqlConfig": "DatabasePostgresqlConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseRedisConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseRedisConfig:DatabaseRedisConfig": "DatabaseRedisConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseReplica",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseReplica:DatabaseReplica": "DatabaseReplica"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseUser",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseUser:DatabaseUser": "DatabaseUser"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/databaseValkeyConfig",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/databaseValkeyConfig:DatabaseValkeyConfig": "DatabaseValkeyConfig"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/dnsRecord",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/dnsRecord:DnsRecord": "DnsRecord"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/domain",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/droplet",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/droplet:Droplet": "Droplet"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/dropletAutoscale",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/dropletAutoscale:DropletAutoscale": "DropletAutoscale"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/dropletSnapshot",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/dropletSnapshot:DropletSnapshot": "DropletSnapshot"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/firewall",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/floatingIp",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/floatingIp:FloatingIp": "FloatingIp"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/floatingIpAssignment",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/floatingIpAssignment:FloatingIpAssignment": "FloatingIpAssignment"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiAgent",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiAgent:GenaiAgent": "GenaiAgent"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiAgentKnowledgeBaseAttachment",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiAgentKnowledgeBaseAttachment:GenaiAgentKnowledgeBaseAttachment": "GenaiAgentKnowledgeBaseAttachment"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiAgentRoute",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiAgentRoute:GenaiAgentRoute": "GenaiAgentRoute"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiFunction",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiFunction:GenaiFunction": "GenaiFunction"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiKnowledgeBase",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiKnowledgeBase:GenaiKnowledgeBase": "GenaiKnowledgeBase"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiKnowledgeBaseDataSource",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiKnowledgeBaseDataSource:GenaiKnowledgeBaseDataSource": "GenaiKnowledgeBaseDataSource"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/genaiOpenaiApiKey",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/genaiOpenaiApiKey:GenaiOpenaiApiKey": "GenaiOpenaiApiKey"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/kubernetesCluster",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/kubernetesCluster:KubernetesCluster": "KubernetesCluster"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/kubernetesNodePool",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/kubernetesNodePool:KubernetesNodePool": "KubernetesNodePool"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/loadBalancer",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/monitorAlert",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/monitorAlert:MonitorAlert": "MonitorAlert"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/partnerAttachment",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/partnerAttachment:PartnerAttachment": "PartnerAttachment"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/project",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/project:Project": "Project"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/projectResources",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/projectResources:ProjectResources": "ProjectResources"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/reservedIp",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/reservedIp:ReservedIp": "ReservedIp"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/reservedIpAssignment",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/reservedIpAssignment:ReservedIpAssignment": "ReservedIpAssignment"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/reservedIpv6",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/reservedIpv6:ReservedIpv6": "ReservedIpv6"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/reservedIpv6Assignment",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/reservedIpv6Assignment:ReservedIpv6Assignment": "ReservedIpv6Assignment"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/spacesBucket",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/spacesBucket:SpacesBucket": "SpacesBucket"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/spacesBucketCorsConfiguration",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/spacesBucketCorsConfiguration:SpacesBucketCorsConfiguration": "SpacesBucketCorsConfiguration"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/spacesBucketLogging",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/spacesBucketLogging:SpacesBucketLogging": "SpacesBucketLogging"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/spacesBucketObject",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/spacesBucketObject:SpacesBucketObject": "SpacesBucketObject"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/spacesBucketPolicy",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/spacesBucketPolicy:SpacesBucketPolicy": "SpacesBucketPolicy"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/spacesKey",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/spacesKey:SpacesKey": "SpacesKey"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/sshKey",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/tag",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/uptimeAlert",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/uptimeAlert:UptimeAlert": "UptimeAlert"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/uptimeCheck",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/uptimeCheck:UptimeCheck": "UptimeCheck"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/volume",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/volumeAttachment",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/volumeAttachment:VolumeAttachment": "VolumeAttachment"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/volumeSnapshot",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/volumeSnapshot:VolumeSnapshot": "VolumeSnapshot"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/vpc",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/vpcNatGateway",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/vpcNatGateway:VpcNatGateway": "VpcNatGateway"
  }
 },
 {
  "pkg": "digitalocean",
  "mod": "index/vpcPeering",
  "fqn": "pulumi_digitalocean",
  "classes": {
   "digitalocean:index/vpcPeering:VpcPeering": "VpcPeering"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "digitalocean",
  "token": "pulumi:providers:digitalocean",
  "fqn": "pulumi_digitalocean",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetReservedIpv6Result',
    'AwaitableGetReservedIpv6Result',
    'get_reserved_ipv6',
    'get_reserved_ipv6_output',
]

@pulumi.output_type
class GetReservedIpv6Result:
    """
    A collection of values returned by getReservedIpv6.
    """
    def __init__(__self__, droplet_id=None, id=None, ip=None, region_slug=None, urn=None):
        if droplet_id and not isinstance(droplet_id, int):
            raise TypeError("Expected argument 'droplet_id' to be a int")
        pulumi.set(__self__, "droplet_id", droplet_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if region_slug and not isinstance(region_slug, str):
            raise TypeError("Expected argument 'region_slug' to be a str")
        pulumi.set(__self__, "region_slug", region_slug)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)

    @_builtins.property
    @pulumi.getter(name="dropletId")
    def droplet_id(self) -> _builtins.int:
        """
        The Droplet id that the reserved IP has been assigned to.
        """
        return pulumi.get(self, "droplet_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> _builtins.str:
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter(name="regionSlug")
    def region_slug(self) -> _builtins.str:
        """
        The region that the reserved IPv6 is reserved to.
        """
        return pulumi.get(self, "region_slug")

    @_builtins.property
    @pulumi.getter
    def urn(self) -> _builtins.str:
        """
        The uniform resource name of the reserved IPv6.
        """
        return pulumi.get(self, "urn")


class AwaitableGetReservedIpv6Result(GetReservedIpv6Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReservedIpv6Result(
            droplet_id=self.droplet_id,
            id=self.id,
            ip=self.ip,
            region_slug=self.region_slug,
            urn=self.urn)


def get_reserved_ipv6(ip: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReservedIpv6Result:
    """
    ## Example Usage

    Get the reserved IPv6:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    foo = digitalocean.ReservedIpv6("foo", region_slug="nyc3")
    foobar = digitalocean.get_reserved_ipv6_output(ip=foo.ip)
    ```


    :param _builtins.str ip: The allocated IPv6 address of the specific reserved IPv6 to retrieve.
    """
    __args__ = dict()
    __args__['ip'] = ip
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getReservedIpv6:getReservedIpv6', __args__, opts=opts, typ=GetReservedIpv6Result).value

    return AwaitableGetReservedIpv6Result(
        droplet_id=pulumi.get(__ret__, 'droplet_id'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        region_slug=pulumi.get(__ret__, 'region_slug'),
        urn=pulumi.get(__ret__, 'urn'))
def get_reserved_ipv6_output(ip: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetReservedIpv6Result]:
    """
    ## Example Usage

    Get the reserved IPv6:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    foo = digitalocean.ReservedIpv6("foo", region_slug="nyc3")
    foobar = digitalocean.get_reserved_ipv6_output(ip=foo.ip)
    ```


    :param _builtins.str ip: The allocated IPv6 address of the specific reserved IPv6 to retrieve.
    """
    __args__ = dict()
    __args__['ip'] = ip
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getReservedIpv6:getReservedIpv6', __args__, opts=opts, typ=GetReservedIpv6Result)
    return __ret__.apply(lambda __response__: GetReservedIpv6Result(
        droplet_id=pulumi.get(__response__, 'droplet_id'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        region_slug=pulumi.get(__response__, 'region_slug'),
        urn=pulumi.get(__response__, 'urn')))
